@@ -2,12 +2,15 @@ from flask import Flask, Blueprint, request
 from flask_security.utils import verify_password
 from flask_json import as_json
 from flask_login import current_user
+from sqlalchemy.exc import IntegrityError
 
 from flexmeasures import __version__ as flexmeasures_version
+from flexmeasures.api.common.utils.api_utils import catch_timed_belief_replacements
 from flexmeasures.data.models.user import User
 from flexmeasures.api.common.utils.args_parsing import (
     validation_error_handler,
 )
+from flexmeasures.api.common.responses import invalid_sender
 from flexmeasures.data.schemas.utils import FMValidationError
 
 # The api blueprint. It is registered with the Flask app (see app.py)
@@ -70,9 +73,9 @@ def get_versions() -> dict:
     """
     response = {
         "message": "For these API versions a public endpoint is available, listing its service. For example: "
-        "/api/v1/getService and /api/v1_1/getService. An authentication token can be requested at: "
+        "/api/v2_0/getService and /api/v3_0/getService. An authentication token can be requested at: "
         "/api/requestAuthToken",
-        "versions": ["v1", "v1_1", "v1_2", "v1_3", "v2_0"],
+        "versions": ["v1", "v1_1", "v1_2", "v1_3", "v2_0", "v3_0"],
         "flexmeasures_version": flexmeasures_version,
     }
     return response
@@ -83,6 +86,8 @@ def register_at(app: Flask):
 
     # handle API specific errors
     app.register_error_handler(FMValidationError, validation_error_handler)
+    app.register_error_handler(IntegrityError, catch_timed_belief_replacements)
+    app.unauthorized_handler_api = invalid_sender
 
     app.register_blueprint(
         flexmeasures_api, url_prefix="/api"
@@ -105,6 +110,7 @@ def register_at(app: Flask):
     from flexmeasures.api.v1_2 import register_at as v1_2_register_at
     from flexmeasures.api.v1_3 import register_at as v1_3_register_at
     from flexmeasures.api.v2_0 import register_at as v2_0_register_at
+    from flexmeasures.api.v3_0 import register_at as v3_0_register_at
     from flexmeasures.api.dev import register_at as dev_register_at
 
     v1_register_at(app)
@@ -112,4 +118,5 @@ def register_at(app: Flask):
     v1_2_register_at(app)
     v1_3_register_at(app)
     v2_0_register_at(app)
+    v3_0_register_at(app)
     dev_register_at(app)
